@@ -46,8 +46,6 @@ GType poppler_annot_flag_get_type (void) G_GNUC_CONST;
 GType poppler_annot_markup_reply_type_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_ANNOT_EXTERNAL_DATA_TYPE (poppler_annot_external_data_type_get_type())
 GType poppler_annot_external_data_type_get_type (void) G_GNUC_CONST;
-#define POPPLER_TYPE_ANNOT_TEXT_ICON (poppler_annot_text_icon_get_type())
-GType poppler_annot_text_icon_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_ANNOT_TEXT_STATE (poppler_annot_text_state_get_type())
 GType poppler_annot_text_state_get_type (void) G_GNUC_CONST;
 #define POPPLER_TYPE_ANNOT_FREE_TEXT_QUADDING (poppler_annot_free_text_quadding_get_type())
